#
# spec file for package gnome-calculator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2-1_0_1
%define gcisover 1-0_0_0

Name:           gnome-calculator
Version:        45.0.2
Release:        150600.1.1
Summary:        A GNOME Calculator Application
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://wiki.gnome.org/Apps/Calculator
Source0:        https://download.gnome.org/sources/gnome-calculator/45/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  meson >= 0.52.0
BuildRequires:  mpc-devel
BuildRequires:  mpfr-devel
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.40
BuildRequires:  pkgconfig(glib-2.0) >= 2.40
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.40
BuildRequires:  pkgconfig(gtk4) >= 4.4.1
BuildRequires:  pkgconfig(gtksourceview-5) >= 5.2.0
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4.alpha
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)

%description
A GNOME calculator package based on calctool and MP library.

%package -n gnome-shell-search-provider-gnome-calculator
Summary:        GNOME Calculator -- Search Provider for GNOME Shell
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{version}
Supplements:    (gnome-shell and %{name})

%description -n gnome-shell-search-provider-gnome-calculator
This package contains a search provider to enable GNOME Shell to get
search results from GNOME Calculator.

%package -n libgcalc-%{sover}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n libgcalc-%{sover}
This package contains a shared library for %{name}.

%package -n libgci-%{gcisover}
Summary:        GNOME Calculator Library GTK Interface
Group:          System/Libraries

%description -n libgci-%{gcisover}
This package contains a shared library for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}
Requires:       libgcalc-%{sover} = %{version}
Requires:       libgci-%{gcisover} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

#check
#meson_test

%post -n libgcalc-%{sover} -p /sbin/ldconfig
%postun -n libgcalc-%{sover} -p /sbin/ldconfig
%post -n libgci-%{gcisover} -p /sbin/ldconfig
%postun -n libgci-%{gcisover} -p /sbin/ldconfig

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}
%{_bindir}/gnome-calculator
%{_bindir}/gcalccmd
%{_datadir}/metainfo/org.gnome.Calculator.appdata.xml
%{_datadir}/applications/org.gnome.Calculator.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.calculator.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Calculator*.svg
%{_mandir}/man1/gnome-calculator.1%{?ext_man}
%{_mandir}/man1/gcalccmd.1%{?ext_man}

%files -n gnome-shell-search-provider-gnome-calculator
%{_datadir}/dbus-1/services/org.gnome.Calculator.SearchProvider.service
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Calculator-search-provider.ini
%{_libexecdir}/gnome-calculator-search-provider

%files -n libgcalc-%{sover}
%{_libdir}/libgcalc-2.so.*

%files -n libgci-%{gcisover}
%{_libdir}/libgci-1.so.*

%files devel
%{_includedir}/gcalc-2/
%{_includedir}/gci-2/
%{_libdir}/libgcalc-2.so
%{_libdir}/pkgconfig/gcalc-2.pc
%{_libdir}/pkgconfig/gci-1.pc
%{_libdir}/libgci-1.so
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/GCalc-2.gir
%{_datadir}/gir-1.0/GCi-1.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gcalc-2.*
%{_datadir}/vala/vapi/gci-1.*

%files lang -f %{name}.lang

%changelog
* Sat Sep 16 2023 bjorn.lie@gmail.com
- Update to version 45.0.2:
  + Updated translations.
* Sun Sep  3 2023 bjorn.lie@gmail.com
- Update to version 45.0.1:
  + Updated translations.
* Wed Aug 16 2023 bjorn.lie@gmail.com
- Update to version 45.0:
  + Search provider performance improvements.
  + Use numeric font instead of monospace.
  + Fixed electron-volt unit abbreviation.
  + Fixed erroneous Joule unit name.
  + Fixed missing build dependency.
  + Updated translations.
* Fri Aug  4 2023 bjorn.lie@gmail.com
- Update to version 45.beta:
  + Fixed variable and function popover reverse typing.
  + Better left/right cursor key handling.
  + Improved toolbar using Adwaita library.
  + Flatpak build improvements.
  + Updated translations.
* Tue Jul 11 2023 bjorn.lie@gmail.com
- Update to version 45.alpha:
  + Remember window size
  + Allow opening Main Menu by pressing F10
  + Extend bit-shifting limit
  + Added new energy units
  + Added TWD support via Bank of Canada rates
  + Added legal section for exchange rate source attribution
  + Added United Nations Treasury exchange rate datasource
  + Added Jamaican Dollar currency
  + Added Ukrainian hryvnia currency
  + Added Nigerian Naira currency
  + Changed symbolic icon to C on the clear button
  + Dropped VEF currency support
  + Use new vala-nightly SDK extension for flatpak
  + Updated translations.
* Fri Mar 17 2023 bjorn.lie@gmail.com
- Update to version 44.0:
  + Updated translations.
* Sun Mar  5 2023 bjorn.lie@gmail.com
- Update to version 44.rc:
  + Updated translations.
* Thu Feb 23 2023 bjorn.lie@gmail.com
- Update to version 44.beta:
  + Improved factorization
  + Number format selection documentation improvements
  + Made builtin function descriptions translatable
  + Fixed display showing 0 on startup
  + Improved button tooltips
  + Added signed int support to programming mode
  + i and e constants updated according to ISO 80000-2:2009
  + Help overlay updates
  + Added preferences shortcut
  + Destroy dialog after clicking cancel
  + Updated translations.
* Fri Sep 16 2022 bjorn.lie@gmail.com
- Update to version 43.0.1:
  + Fixed appdata versioning.
* Fri Sep 16 2022 bjorn.lie@gmail.com
- Update to version 43.0:
  + Removed old issue tracker references.
* Sun Sep  4 2022 emilyyrose@gmail.com
- Updated to version 43.rc:
  + Fix crash when entering new function name.
  + Fix source view border.
  + Flatpak build update.
  + Port about window to libadwaita.
  + Port to libsoup3.
  + Updated translations.
  + Drop patch 4fff5e1.patch due to libsoup3 being patched upstream
* Thu Sep  1 2022 bjorn.lie@gmail.com
- Add 4fff5e1.patch: Build with soup3. Following this, replace
  pkgconfig(libsoup-2.4) with pkgconfig(libsoup-3.0) BuildRequires.
* Fri Jul  8 2022 bjorn.lie@gmail.com
- Update to version 43.alpha:
  + Fixed broken undo/redo.
  + Make sure variable name definitions work with whitespace too.
  + Fix translatable strings.
  + Fixed missing implicit multiplication with variable and root.
  + Meson warning fixes.
  + Updated translations.
* Sun Jul  3 2022 emilyyrose@gmail.com
- Update to version 42.2:
  + Fixed incorrect history with bits toggling.
  + Fixed crash when typing in variable popover.
  + Fixed incorrect libxml usage.
  + Updated translations.
* Mon May 30 2022 dimstar@opensuse.org
- Update to version 42.1:
  + Fixed broken undo/redo.
  + Removed automatic closing brace addition.
  + Fixed incorrect percentage symbol precedence handling.
  + Updated translations.
* Sun Mar 20 2022 bjorn.lie@gmail.com
- Update to version 42.0:
  + Updated translations.
* Sun Mar  6 2022 bjorn.lie@gmail.com
- Update to version 42.rc:
  + Use new gnome post_install script
  + gcalc build fixes
  + Updated screenshots
  + Set default focus to entry
  + Updated translations.
* Mon Feb 14 2022 bjorn.lie@gmail.com
- Update to version 42.beta:
  + Fixed build issues with GCI entry controller tests
  + Force LTR in history view
  + programing mode: Force bit digits to be always LTR
  + Use AdwApplication
  + ui: Fix styles
  + Updated translations.
* Mon Jan 10 2022 dimstar@opensuse.org
- Update to version 42.alpha:
  + build: migrated to GTK4.
  + entry: Added currencies completion provider.
  + entry: Fixed percentage evaluation error.
  + internal: Moved history view from MathDisplay to MathWindow.
  + window: set default width for basic and keyboard mode.
  + buttons: removed destructive action class from clear button.
  + converter: search support in unit selector, separate conversion
    category selector.
  + Updated translations.
- Update BuildRequires for port to GTK4:
  + Replace pkgconfig(gtk+-3.0)with pkgconfig(gtk4)
  + Replace pkgconfig(gtksourceview-4) with
    pkgconfig(gtksourceview-5)
  + Drop pkgconfig(libhandy-1)
  + Add pgkconfig(libadwaita-1)
- Update format of Supplements from packageane() to regular RPM
  boolean deps.
* Mon Dec  6 2021 bjorn.lie@gmail.com
- Update to version 41.1:
  + Do not force width for basic mode.
  + Updated translations.
* Sun Sep 19 2021 mgorse@suse.com
- Update to version 41.0:
  + Use first translated symbol for conversion with button.
  + Appdata includes hardware support information.
  + Updated Translations.
* Thu Sep 16 2021 sbrabec@suse.com
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Sep  4 2021 bjorn.lie@gmail.com
- Update to version 41.rc:
  + Updated translations.
* Fri Aug  6 2021 dimstar@opensuse.org
- Update to version 41.alpha:
  + Adaptive preferences window.
  + Fixed currency conversion using convert button.
  + User interface reworked, adaptive UI.
  + Enlarged calculator icon in help.
  + Fixed kilohertz shorthand.
  + Added support using calculator without currency conversion for
    privacy.
  + Added support for function description of custom functions
    using @.
* Fri Apr 30 2021 dimstar@opensuse.org
- Update to version 40.1:
  + Fixed currency conversion using the convert button.
  + Fixed preferences switch state.
  + Updated translations.
* Sat Mar 20 2021 mgorse@suse.com
- Update to version 40.0:
  + Updated translations.
* Thu Mar 18 2021 dimstar@opensuse.org
- Update to version 40.rc:
  + Resize window after switching mode.
  + Fixed compilation warnings.
  + Support offline currency conversion tests.
  + Use official unit on conversion button click.
  + Fixed temperature unit typos.
  + Ellipsize conversion labels.
  + Added Ctrl+Delete shortcut for clearing the current equation.
  + Allow multiple decimal points #166.
  + Added Ctrl+O shortcut for degrees symbol.
  + Use gtk-sourceview 4.8.
  + Updated translations.
* Tue Feb  9 2021 dimstar@opensuse.org
- Update to version 40.beta:
  + Fixed issues with initial loading of currencies.
  + Rework currency retrieval preparing for currency provider
    plugins.
  + Fixed commandline conversions.
  + Added currency conversion tests.
  + Added support for frequencies conversion.
  + Added support for converting to and from weeks.
  + Added support for converting to and from centuries and decades.
  + Increase buttons font size.
  + Added %% button to Advanced mode.
  + Show 4 decimals in converter instead of only two.
  + Added style classes to buttons.
  + Updated translations.
* Tue Jan 12 2021 dimstar@opensuse.org
- Update to version 40.alpha:
  + Use libhandy for window and headerbar.
  + Use C instead of Clr in help.
  + Fixed broken currency conversion on first start.
  + Removed duplicate word from help.
  + Added lbs shortcut for pounds conversion.
  + Fixed inconsistent word size.
  + Removed unused trunc button from programming mode.
  + Fixed deprecation warnings.
  + Added Serbian Dinar with fixed rate.
  + Added Bangladeshi Taka with fixed rate.
  + Updated mailing list contact to Discourse.
  + Added basic help page for programming mode.
  + Added insert character code button.
  + Dim inapplicable bits on word size change.
  + Make the conversion labels selectable.
  + Do not convert on swap.
  + Word size changer in programming mode.
  + Added metric cups conversion unit.
  + Fixed astronomical unit conversion.
  + Fixed feet-based units name, added mph and kph shortcuts.
  + Use shell copy to clipboard action.
  + Fixed preferences of angle units.
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
- Disable test-suite for the time being: does not find the schema
  (works on package level due to file triggers).
* Sat Nov 21 2020 bjorn.lie@gmail.com
- Update to version 3.38.2:
  + Fixed radians and degrees preference swapped.
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Fixed GNOME Shell search result copy to clipboard.
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Add tooltips for bits in programming mode.
  + Added speed conversions.
  + History view follows preferences.
  + Added month as time unit.
  + Better help for variables example usage.
  + Defined pi variable, added pi button in programming mode.
  + Updated app icon.
  + Fixed bug returning empty string as result.
  + Support latex-style multiplication.
  + Added support for tau constant.
  + Unify constant handling.
  + Separate UI files from sources.
  + Moved number format selection to separate menu.
  + Replaces mode selector shortcuts with Ctrl+Alt.
  + Clear answer if editing right before it.
  + Moved preferences dialog to UI file.
  + Refresh bits panel after calculation.
  + Removed past author addresses.
  + Updated translations.
* Sun Mar  8 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Fixed broken markup in UI translations.
  + Updated translations.
* Sat Feb 29 2020 mgorse@suse.com
- Update to version 3.35.92:
  + doc: Don't pass --fatal-warnings to valadoc.
  + Removed obsolete keyboard shortcut.
  + help: Update icon for 3.36.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Drop padding around the display.
  + Updated Keyboard Shortcuts.
  + Handle Escape and Enter correctly with completion.
  + Added F10 for primary menu shortcut.
  + Added Rack Units to the conversions.
  + Fixed freeze on calculating atan(+/-i).
  + Fixed mode shortcuts by removing blocking mnemonics.
  + Implemented result history browsing using alt left/right.
- Changes from version 3.35.2:
  + List possible modes in commandline help.
  + Add square feet unit.
  + Base conversion display selectable.
  + Updated translations.
- Split out new library into libgci-1-0_0_0 subpackage.
* Mon Oct  7 2019 bjorn.lie@gmail.com
- Update to version 3.34.1:
  + Created nightly app icon.
  + Snap build improvements.
  + Updated translations.
* Tue Sep 10 2019 qkzhu@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Mon Sep  2 2019 bjorn.lie@gmail.com
- Update to version 3.33.92:
  + README updates.
  + Updated translations.
- Changes from version 3.33.90:
  + Flatpak build cleanup.
  + Debug messages cleanup.
  + Updated translations.
- Changes from version 3.33.3:
  + calculator library build fixes.
  + CI build fixes.
  + Added mnemonics for primary menu items.
  + Dropped leading zeros octal prefix.
  + Updated translations.
- Changes from version 3.33.2:
  + Separated calculator library.
  + Ensure icon is available for shell.
  + Support entering left/right shift with keyboard.
  + Fixed CFA conversion rate.
  + Remove copy icon from search provider results.
  + Do not assume octal base for binary numbers.
  + Show thousands separator in unit converter.
  + Use currency name instead of display name for conversion.
  + Quit warns and closes all windows.
  + Avoid normalizing the equation twice in search.
  + Ignore keypresses while calculating results.
  + Only allow one decimal point in numbers.
  + Application icon updated in help.
  + Updated translations.
- Add pkgconfig(gee-0.8) BuildRequires: New dependency.
- Package new sub-packages gnome-calculator-devel and libgcalc-1.
  Also handle shared library in post(un), and set needed Requires
  in devel package.
* Wed Jun 26 2019 bjorn.lie@gmail.com
- Update to version 3.32.2:
  + Snap build updates.
  + Fixed numbers with octal prefix.
  + Updated translations.
* Tue Jun  4 2019 bjorn.lie@gmail.com
- Drop unneeded and unused update-desktop-files BuildRequires.
* Wed Apr 10 2019 bjorn.lie@gmail.com
- Update to version 3.32.1:
  + Snap build update.
  + Fixed CFA conversion rate.
  + Removed copy icon from search provider result.
  + Do not assume octal base for binary numbers.
  + Use currency name instead of display name for conversion.
  + Updated application icon in help.
  + Fixed search provider results broken.
  + Ignore keypresses while calculating result.
  + Only allow entering one decimal point.
  + Use meson build compatible with older meson.
  + Show thousands separator in unit converter.
  + Updated translations.
* Mon Mar 11 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.92:
  + Updated translations.
* Mon Feb 18 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Exchange rate update interval preference.
  + Updated and fixed appdata.
  + Fix for digit transformed into ^ on double *.
  + Accept comma and decimal point as decimal separator.
  + Updated translations.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Added Alt+T shortcut for keyboard mode.
  + Use US prefix for non-imperial units.
  + Updated translations.
- Changes from version 3.31.2:
  + Readded missing accelerators.
  + Use GLib.List.deep_copy() to fix argument type mismatch.
  + Write all settings at once using delayed backend.
  + Updated translations.
- Changes from version 3.31.1:
  + Search provider improvements.
  + Copy to clipboard from search result.
  + Conversion UI improvements.
  + Functions and variables popover HIG fixes.
  + Port to GtkSourceView 4.
  + Remove appmenu.
  + Application icon and symbolic icon update.
  + Fixed new window shell action.
  + Mark 'in' conversion keyword as translatable.
  + Support for integer decimals in different bases.
  + Mark some untranslatable texts as translatable.
  + Use application icon in about and window icon instead of
    generic icon.
- Replace pkgconfig(gtksourceview-3.0) with
  pkgconfig(gtksourceview-4) BuildRequires following upstreams
  port.
- Add meson_check macro in check section, run tests.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix opening multiple windows in GNOME Shell.
  + Updated translations.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + Updated snap to build with meson.
  + Updated translations.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Fixed flatpak build issues.
  + Fixed naming of Turkish lira currency.
  + Added OARS metadata.
  + CI configuration.
  + Updated translations.
* Fri Jun 22 2018 luc14n0@linuxmail.org
- Update to 3.29.3:
  + Use Mass instead of Weight for mass units
    (glgo#GNOME/gnome-calculator#67).
  + Updated translations.
* Mon Jun 18 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Fix currencies not loading (glgo#GNOME/gnome-calculator#66).
  + Updated translations.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 luc14n0@linuxmail.org
- Update to 3.27.92:
  + Fixed icon sizes (bgo#793263).
  + Calculator display black box fixes (bgo#793157).
  + Updated translations.
- Update URL tag to https://wiki.gnome.org/Apps/Calculator: the
  current Calculator's web page.
- Drop libtool, intltool and appstream-glib-devel BuildRequires
  and add meson; replace configure/make/make_install macros by
  meson equivalents meson/meson_build/meson_install. All of these
  changes reflect the upstream port to Meson build system and the
  improvements made to turn it reliable or at least buildable.
- Add glib-2.0 and gmodule-export-2.0 pkgconfig modules
  BuildRequires to avoid implicit dependencies.
- Drop glib2_gsettings_schema_requires macro: it is no longer
  required since RPM file triggers.
- Drop update-desktop-files BuildRequires and its macro: they are
  no longer needed anymore.
- Point fdupes to the data directory rather than directly to the
  buildroot, which is a practice that must be avoided.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Changed clear symbolic icon with C (bgo#792844).
  + Made the calculator window resizable (bgo#756920).
  + Sane required width for history view (bgo#788395).
  + Support for gcalccmd command-line arguments (bgo#788872).
  + Ellipsize equation in search provider instead of result
    (bgo#759876).
  + Avoid scrollbar overlapping equation (bgo#770246).
  + Return with failure in case of precision error (bgo#749336).
  + Added bried explanation of functions (bgo#748897).
  + Changed overflow error message (bgo#745708).
  + Added keyboard shortcut to clear history (bgo#792814).
  + Added meson build files (bgo#783062).
  + Deprecated calls replaced.
  + Rename icon directive in flatpak to have icon on flathub.
  + Check the locale before using it (bgo##793098).
  + Fixed black rectangle on equation entry scrolling (bgo#793157).
  + Updated translations.
- Add libtool,intltool, appstream-glib-devel and vala
  BuildRequires: since upstream introduced also the meson build
  system, the tarball is no longer bootstrapped. Build using meson
  though is not working to our satisfaction yet.
* Tue Nov 14 2017 fezhang@suse.com
- Update to version 3.27.2:
  + Fix cosh and sinh buttons (bgo#788409).
  + Ship app icon with Calculator.
  + Added stone unit (bgo#789333).
  + Replaced ln button with log2 in programming mode (bgo#789152).
  + Use _ instead of ans for last result (bgo#785107).
  + Fixed critical warning after first operation (bgo#785108).
  + Updated translations.
* Thu Nov  2 2017 badshah400@gmail.com
- Update to version 3.26.0:
  + Fix gettext-domain.
  + Updated translations.
* Wed Sep  6 2017 luc14n0@linuxmail.org
- Update to version 3.25.92:
  + Updated translations.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Updated translations.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Fixed incorrect bit toggle buttons (bgo#785850).
  + Re-enable Portuguese help translation (bgo#784427).
  + Stop using deprecated calls.
  + Fixed appdata validation (bgo#784033).
  + Fixed appdata.xml installation (bgo#783986).
  + Updated translations.
- Drop gnome-calculator-appdata.patch: Fixed upstream, following
  this, drop libtool and appstream-glib-devel BuildRequires and
  autoreconf call.
- Drop post(un) handling, no longer needed. This means dropping
  glib2_gsettings_schema_post(un) and desktop_database_post(un)
  macros, file-triggers takes care of this now.
- Drop obsolete clean section.
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Stop using intltool.
  + Fix XML tags in Portuguese help translation.
  + Move resources into src directory.
  + Updated translations.
- Drop intltool BuildRequires: no longer needed after upstreams
  changes.
- Add gnome-calculator-appdata.patch: Fix build system to install
  appdata.xml file.
- Add libtool and appstream-glib-devel BuildRequires and call
  autoreconf in %%prep, as above patch touches the build system.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Update parser to allow complex conversions.
  + Updated translations.
* Tue Mar 21 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Added flatpak manifest.
  + Updated translations.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Fixed unit conversion from negative constant numbers
    (bgo#778311).
  + Better error highlighting.
  + Fix null token causing segfault.
  + Set application id (bgo#778228).
  + Documentation for the history view (bgo#681935).
  + Added Desktop Publishing Point length unit (bgo#778449).
  + Use angle units from settings in search provider (bgo#778274).
  + Fixed incorrect value for ans in variable popup (bgo#778242).
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.4:
  + Bugs fixed: bgo#773688, bgo#775759.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.3:
  + Flatpak packaging fixes.
  + Added additional temperature unit shortcuts for conversion
    (bgo#775300).
  + Use proper chain-up syntax.
  + Updated translations.
- Change desktop files call in suse_update_desktop_file macro run.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Remember window position.
  + Use Unicode in translatable strings.
  + Use GtkPopovers for memory and function buttons (bgo#748742).
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Migrate to GtkGrid from deprecated GtkTable API (bgo#767394).
  + Use localized window title (bgo#768432).
  + Preferences dialog update (bgo#746599).
  + Add option to start window in mode (bgo#748135).
  + Fix help typo (bgo#748894).
  + Fix reusing items from history (bgo#766155).
  + Use MPC for complex numbers (bgo#759439).
  + Fix bit panel and base label when base has changed
    (bgo#732685).
  + Ctrl+Backspace should delete only the last number (bgo#725114).
  + Use Actions for buttons (bgo#771635).
  + Add round, floor, ceil, sgn to docs (bgo#748895).
  + Rename Pound Sterling to British Pound Sterling (bgo#664366).
  + Fix possible errors on currency conversion (bgo#750672).
  + Add new window appmenu entry (bgo#724478).
  + Fix markup error in about (bgo#772990).
  + Add accels for changing mode (bgo#740503).
  + History view styling (bgo#743499).
  + Window layout fixes (bgo#743538).
  + Remov unnecessary scrolledwindow (bgo#768656).
  + Add keyboard shortcuts window (bgo#772735).
  + Fix first expression with parentheses (bgo#700617).
  + Add shortcut to close current window (bgo#755398).
  + Fix conversion unit change (bgo#748732).
  + Fixed conversion user interface for LTR (bgo#711587).
  + Updated translations.
- Add mpc-devel BuildRequires: new dependency.
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 3.22.3:
  + Complex exponentiation fixes (lp#1566513).
* Fri Nov 11 2016 firebird209@gmail.com
- Update to version 3.22.2:
  + Fixed conversion unit switch.
  + Fixed first expression with parentheses.
  + Fixed possible errors on currency conversion.
  + Ctrl+Backspace should only delete last number.
  + Fixed reusing results from the history stack.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Headerbar layout fixes.
  + Use dim labels for bit markers in Programming mode.
  + Fixed history scrolling.
  + Minor programming errors fixed.
  + Vertically center headerbar button content.
  + Updated styles for gtk+ 3.20.
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Fix base change for log, fixes bgo#748729.
  + Math buttons: fix a (potential) crash loading financial
    dialogs.
  + Updated translations.
* Mon Sep 12 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Fix the build.
  + Updated translations.
* Sat Aug 20 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Added 'period' keypress when the delete key on the numpad is
    pressed.
  + lib: prevents segfault when elements of division to zero have
    null assigned tokens (bgo#769364).
  + Add Language headers to po files.
  + Updated translations.
* Sat Aug 20 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Distribute history-view.ui and history-entry.ui.
  + Updated translations.
- Drop gcalctool and gcalctool-lang Obsoletes: Removed since 3.8.0
  release, there is no openSUSE release with GNOME that old.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Drop history-entry.ui and history-view.ui: No longer missing.
* Sat Aug 20 2016 dimstar@opensuse.org
- Add history-entry.ui and history-view.ui as sources: they were
  missing in the tarball.
* Mon Aug  1 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + lib: prevents segfault when elements of division to zero have
    null assigned tokens (bgo#769364).
  + Updated translations.
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 3.20.1 (fate#318572):
  + Fix: precedence of root operator.
  + Updated translations.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop bnc945603-fix-undo-ans-error.patch: fixed upstream.
- Drop gnome-calculator-rename-desktop-file.patch: fixed upstream.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Udated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Fix: Check for null on variables ought to autocomplete
    (bgo#762426).
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + New: Upgrade license for all source files to GPLv3+.
  + New: Use Soup instead of GVFS to download the IMF/ECB currency
    data.
  + Fix: Silence a compiler warning.
  + Fix: Remove Lithuanian litas from currency list.
  + Fix: Fix use of GtkStyleContext for GTK+ 3.20,
  + Fix: Clarify license on number.vala.
  + Fix: Clarify license on mpfr.vapi.
  + Fix: Installed tests: Update expectations.
  + Fix: Set the accessible name on the mode chooser.
  + Fix: Do not reset second currency on first currency change
    (bgo#260166).
  + Fix: Fix Chinese Yuan symbol (bgo#761075).
  + Fix: Add a missing tag to the AppData file.
  + Update: Upgrade appdata
  + Udated translations.
- Add pkgconfig(libsoup-2.4) BuildRequires: new dependency.
* Fri Jan 29 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Migrate MathConverter, MathWindow, HistoryView and HistoryEntry
    to GtkBuilder template.
  + Remove unused -D defines from Makefile.am and configure.vapi
    for both src/ and lib/.
  + Check if base exponent are complex for xpowy() method.
  + Prevent infinte loop on some operations with imaginary numbers
    (bgo#757657).
  + e^(-0.5) returned the wrong value (bgo#756960).
  + Missing mnemonic bond in Gross Profit Margin dialog.
  + Use load_from_resource in the Gtk.CssProvider instead of
    opening the file manually.
  + Use builddir for gresource.xml to satisfy Vala/autotools
    behaviour (bgo#760679).
  + Rename gnome-calculator.doap name tag to GNOME Calculator
    instead of gnome-calculator.
  + Use AM_DISTCHECK_CONFIGURE_FLAGS.
  + MathDisplay grabs focus after being shown (bgo#748743).
  + math-equation: "No history" message should disappear when
    appropriate (bgo#759943).
  + Updated translations.
* Fri Jan 29 2016 zaitor@opensuse.org
- Update to version 3.19.2:
  + Updated translations.
* Fri Jan 29 2016 zaitor@opensuse.org
- Update to version 3.19.1:
  + Fix: Explicitly link required libraries for gnome-calculator
    and gcalcmd binaries.
  + Updated translations.
- Add an explicit pkgconfig(gobject-2.0) BuildRequires as configure
  checks for it now.
* Wed Jan 27 2016 zaitor@opensuse.org
- Update to version 3.18.3:
  + Fix:
  - Chinese Yuan symbol (bgo#761075).
  - MathDisplay grabs focus after being shown (bgo#748743).
  - Missing mnemonic bond in Gross Profit Margin dialog.
  - Check if base exponent are complex for xpowy() method.
  - Prevent infinte loop on some operations with imaginary
    numbers (bgo#757657).
  - e^(-0.5) returned the wrong value (bgo#756960).
* Tue Nov 24 2015 cxiong@suse.com
- Add bnc945603-fix-undo-ans-error.patch (bnc#945603)
  + Fix GNOME Calculator undo errors.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix: Explicitly link required libraries to avoid build problems
    under certain setups.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Fix: SYD function was returning the wrong value.
  + Fix: Fix dialogs sizing for financial functions.
  + Updated translations.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Misc build system fixes.
  + Updated translations.
* Thu Jun 25 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Update: Stop using gnome-common.
  + Fix: Remove incorrect assertion in search provider.
* Fri Jun 12 2015 dimstar@opensuse.org
- Update to version 3.17.2:
  + Split many files into an internal convenience library.
  + Remove workaround for bgo#737222.
  + Updated translations.
- Pass --disable-static to configure: we do not have a use for the
  internal helper library as a static lib.
* Fri Jun 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix: Search provider crash introduced by 3.16.1.
* Fri May 22 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fix: Search provider should discard child stdout/stderr.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Remove red color from clear button.
  + Update "Powers" page in documentation.
  + Updated translations.
* Sat Jan 24 2015 badshah400@gmail.com
- Update to versin 3.15.4:
  + New:
  - Keyboard mode.
  - MPFR back-end.
  - Digital Storage conversion.
  + Update:
  - Switch to GPLv3+ license.
  - Case-insensitive conversion units.
  - Don't copy thousand separators to clipboard.
  + Fix:
  - Use HTTPS for downloading exchange rates.
  - Repeated entries in history view.
  - Padding in UI buttons.
  - Style history view boarder.
  - Sort currencies based on locale.
  - Deprecated use-stock property.
  - Download missing exchange rates on first launch.
  - Missing buildtime dependency.
  - gtksourceview binding change.
  + Updated translations.
- Add mpfr-devel to BuildRequires.
- Update License tag in specfile.
* Thu Dec  4 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + New:
  - Colored buttons.
  - History view.
  + Update:
  - Update to latest GtkSourceView API.
  - Support upcoming Vala 0.27.
  - Increase search provider timeout.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Update: Search provider timeout.
  + Workaround: Warning in search-provider log.
  + Fix:
  - Crash on thousand saperator.
  - Button arrangement in programming mode.
  - Vala warning about empty conditional body.
  - Remove use of GtkAlignment.
  - Use set_accels_for_action().
  + Removed:
  - Gtk.Widget.ensure_style().
  - Use of fixes.vapi for langinfo.
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fix: Documentation.
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Fix: test install.
  + Updated translations.
* Thu Jul 17 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + New features:
  - Calculator search provider.
  - Tests in release tarball.
  - Localized radix character from command-line.
  + Bugs fixed:
  - Restore previous answer on undo.
  - Segfault on undo beyond history.
  - Malformed expression error on base change.
  - Critical warnings when entering Financial Mode.
  - Fix gcalccmd crash.
  - gcalccmd now exits with new-line.
  - Reset text in new function pop-up.
  - Removed redundent calls to notify_property().
  - Use layout based decimal saperator on numberpad.
  - Appdata: add default screenshot.
  - Don't create fundamental types.
  - Typo in step definition filelist.
  - Removed: Latvian lats from default currencies.
  + Updated translations.
- Split new package gnome-shell-search-provider-gnome-calculator.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Use popover to change mode.
  + Use headerbar for preference dialog.
  + Update: GTK+ and vala dependencies.
  + Update: Modernize option parsing.
  + Update: URLs in doap file.
  + Update: License fields in appdata.
  + Fix: Ignore libtool files.
  + Fix: Failing test-case due to updated libc.
  + Fix: Crash due to non-validated return iterator.
  + Fix: Close popover after changing mode.
  + Fix: Focus input field after mode change.
  + Fix: Mark image not translatable.
  + Fix: Crash on sub/superscript with trailing space.
  + Updated translations.
* Mon May 19 2014 mgorse@suse.com
- Add gnome-calculator-rename-desktop-file.patch: fix broken
  dependency (bnc#878343).
- Fix suse_update_desktop_file.
* Thu Apr 10 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Fix crash on entering decimal saperator.
  + Fix failing test-case.
  + Remove unimplemented trunc button.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Fix: Lost text focus on click.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Fix Precision loss.
  + Fix 0^0 should be indeterminate.
  + Fix Precision error for ln () calculations.
  + Build fixes and improvements.
  + Rename desktop file.
  + Updated translations.
* Wed Mar  5 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Fix :
  - Window specific mode and actions.
  - About dialog.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Fix Appdata.
  + Updated translations.
- Drop gnome-calculator-appdata_xml.patch: fixed upstream, with a
  slight different approach (other screenshot URLs references).
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Fixes:
  - Add tooltip to custom functions.
  - Bug in representation mode for non-decimal answers.
  + Updated translations.
* Wed Mar  5 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + New:
  - Custom functions.
  - Support for factorials of positive decimal numbers.
  + Updated:
  - Depend on newer versions of GTK, Vala.
  - Use HeaderBar.
  + Fixes:
  - Stop using stock icons.
  - Compilation warnings.
  - Typos.
  - AppData.
  - Misc cleanup.
  + Updated translations.
- Add pkgconfig(gtksourceview-3.0) BuildRequires: new dependency.
* Wed Mar  5 2014 coolo@suse.com
- Add gnome-calculator-appdata_xml.patch: URI encode the links to
  screenshots inside appdata.xml.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2:
  + Fixed about dialog title.
  + Fixed multi-line wrap bug, replace newline characters.
  + Fixed "Malformed expresson" bug.
  + Updated translations.
* Sat Oct 19 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add Appdata.
  + Updated translations.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix precedence related bugs.
  + Fix app name in about dialog.
  + Add logo to help index.
  + Update man page.
  + Fix desktop file (bgo#699073).
  + Updated translations.
* Wed Jul 10 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Fix TextBufferIterator bug in base conversion.
  + Updated documentation.
* Thu Jun 20 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Updated translations.
* Wed May 29 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Improve integer exponentiation & factorization.
  + Fix modular exponentiation calculation error.
  + Fix consecutive squaring crash.
  + Use .ui file for app menu.
  + Fix uninitialized variable.
  + Workaround for gtk_builder_add_objects_from_resource().
  + Fix .doap and .ui files (set buttons table as toplevel).
  + Use gresource for .ui files.
  + Fix null pointer dereferrence.
  + Fix compiler warnings.
  + Fix typo.
  + Updated translations.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fix subtract button inserts additional minus.
  + Fix error reporting bug for malformed expression.
  + Fix crash issue with null pointer dereference.
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Fix Desktop file keyword translations.
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Rename gnome-calculator.desktop back to gcalctool.desktop, as
    users could lose their favorited launchers otherwise
    (bgo#695382).
  + Updated translations.
* Thu Mar  7 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Updated translations.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.90 (now follows gnome versions):
  + Updated translations.
- Changes from version 3.7.5:
  + Fix desktop file syntax.
- Changes from version 3.7.4:
  + Add keyword to .desktop file
  + Expressions with base conversions (bgo#690576)
- Changes from version 3.7.3:
  + Correctly calculate modulo division with negative numbers.
  + Don't show numbers in exponential form when within word size in
    programmer mode.
  + Ignore thousands separators in gcalccmd, gnome-calculator -s.
- Changes from version 3.7.2:
  + Fix incorrectly ininitialized option list.
- Changes from version 3.7.1:
  + Renamed to gnome-calculator.
  + Port to Vala.
  + Highlight parts of equation that have caused an error.
  + Fix error reporting not working for certain types of error.
  + Add shadow around display.
- Rename package from gcalctool to gnome-calculator:
  + Obsolete gcalctool(-lang) <= 6.6.2 (last published version).
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 6.6.2:
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 6.6.1:
  + Fix error reporting not working for certain types of error.
  + Add shadow around display.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 6.6.0:
  + Updated translations.
* Mon Sep 17 2012 dimstar@opensuse.org
- Update to version 6.5.92:
  + Allow multiple instances of gcalctool.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 6.5.91:
  + Updated translations.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 6.5.90.1:
  + Remove reference to removed source file.
- Changes from version 6.5.90:
  + Replace lex/bison parser with hand-written parser.
  + Use g_warning not g_error when unable to parse currency file.
- Drop bison and flex BuildRequires: no longer required.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 6.5.3:
  + Set window icon correctly
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 6.5.1:
  + Port to GtkApplication.
  + Replace menubar with a GMenu.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 6.4.2.1:
  + Fix version in configure.ac (again).
- Changes from version 6.4.2:
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 6.4.1.1:
  + Build fixes.
- Changes from version 6.4.1:
  + Only show thousands separators in decimal mode
  + Add trailing semicolon to .desktop file
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 6.4.0:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Remove hack to find localized help: this has been fixed in
  find-lang.sh.
* Thu Mar 22 2012 vuntz@opensuse.org
- Update to version 6.3.92.1:
  + Fix acos/asin/atan not working
  + Fix help not being correctly installed
- Changes from version 6.3.92:
  + Remove widget background color tints (not working in recent GTK
    themes)
  + Use symbolic icons for clear/undo
- Remove --disable-scrollkeeper from configure: this option is
  gone.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 6.3.5:
  + Build help with yelp-tools instead of gnome-doc-utils
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Change gnome-doc-utils-devel BuildRequires to yelp-tools,
  following upstream change.
- Add the usual hack to correctly detect translated help installed
  in new directory until %%find_lang does it.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 6.3.4:
  + Fix a crash in gcalctool when ECB rate file can't be parsed
  + Fix square centimeter conversions
  + Fix incorrect spelling of Celsius
  + Remove deprecated API usage
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 6.2.0:
  + Updated translations.
* Tue Aug 23 2011 dimstar@opensuse.org
- Update to version 6.1.5:
  + Add CFA franc into currency list.
* Sun Jul 10 2011 vuntz@opensuse.org
- Update to version 6.1.3:
  + Fix crash running on BSD (bgo#650174)
- Changes from version 6.1.0:
  + Fix conversion of nautical miles (bgo#648205)
  + Fix some unit labels that were not in plural form (bgo#644681)
  + Use nmi as label for nautical mile, use nm for nanometers
    (bgo#644682)
  + Mark strings for translation that were missed (bgo#646093)
  + Only write to GSettings when settings change, don't sync on
    exit (bgo#647327)
  + Fix crash when not all currencies downloaded
  + Fix bit editor (bgo#646142)
  + Use K for kelvin, not ˚K (bgo#643585)
  + Add space between number and ˚C
  + Fix 0^n generating error for fractional n (bgo#634066)
  + Support both μs and us for entering microseconds
  + Fix order of implied multiplication
  + Make automatic exponentiation less aggressive
  + Fix thousands separator being on front of three digit numbers
  + Don't clear display when entering digit inside result
  + Add a swap units button (bgo#633193)
  + Drop support for GTK2
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 6.0.2:
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 6.0.1:
  + bgo#648205: fix conversion of nautical miles.
  + bgo#646093: mark strings for translation that were missed.
  + bgo#647327: only write to GSettings when settings change,
    don't sync on exit.
  + Fix crash when not all currencies downloaded.
  + bgo#646142: fix bit editor.
  + bgo#634066: fix 0^n generating error for fractional n.
  + Fix order of implied multiplication.
  + Make automatic exponentiation less aggressive.
  + Fix thousands separator being on front of three digit numbers.
  + Don't clear display when entering digit inside result.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 6.0.0:
  + Use /org/gnome as location for gsettings keys.  This will mean
    gcalctool 5.31.x users will have their settings reset to
    defaults.
  + bgo#645663: correctly choose the first conversion when
    none/invalid defined.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 5.91.93:
  + Updated translations
* Mon Mar 21 2011 fcrozat@novell.com
- Update to version 5.91.92:
  + bgo#645138: Add gcalccmd man page
  + bgo#645137: Remove references to ~/.gcalctoolrc
* Fri Mar 18 2011 fcrozat@novell.com
- Update to version 5.91.91:
  + bgo#644980: disable localized digits.
  + bgo#637328: fix crash doing bitwise operations with large
    numbers.
  + Don't use automatic exponential format when not in base 10.
  + Only use thousands separators in base 10.
  + bgo#640818: set currency on first start.
  + bgo#634904: support entering super/subscript with numeric
    keypad.
* Tue Feb 22 2011 fcrozat@novell.com
- Update to version 5.91.90:
  + Fix grammar mistakes
  + Fix translated conversions (bgo#641166)
- Changes from version 5.91.6:
  + Add fixed rate of 15.6466 EEK = 1 EUR (bgo#639332)
  + Use full name of currency in conversion bar
  + Add temperature conversion
  + Update conversion bar when currencies are updated
  + Fix incorrect display of complex numbers
  + Now able to change currencies from advanced mode
- Changes from version 5.91.5:
  + Make new variable buttons that combines add/set/get and clear
    into one dialog.
  + Add a decimal point button to the programming mode
  + Make the numeric keypad produce numbers even when numlock is on
- Changes from version 5.91.4:
  + Use new Indian Rupee sign (bgo#636587)
  + Use currency rates from the IMF as well as the ECB to add
    24 new rates:
    AED, BHD, BND, BWP, CLP, COP, DZD, ILS, IRR, KWD, KZT, LKR,
    LYD, MUR, NPR, OMR, PEN, PKR, QAR, SAR, TND, TTD, UYU, VEF
  + Don't hide GCalctool in KDE
  + Convert numeric keypad separator into locale specific version
    (bgo#632794)
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Dec 17 2010 vuntz@opensuse.org
- Update to version 5.91.3:
  + Fix incorrect calculation of tanh
  + Fix dropping of decimal points when thousand separator is '.'
    (bgo#635517)
  + Improve conversion bar
  + Fix crash in scientific mode
  + Add new automatic display mode that switches from fixed to
    scientific when numbers are too large
- Changes from version 5.91.2:
  + Fix broken thousands separators code (bgo#628908)
  + Don't make window resizable, it is not supposed to be
  + Use icons for undo and clear buttons as the translations cause
    them to be oversized in some languages
  + Handle Han digits (〇〡〢〣〤〥〦〧〨〩)
  + If a thousands separator is not defined then use ' '
    (bgo#632182)
  + Fix incorrect error text for acosh function (bgo#632614)
- Changes from version 5.91.1:
  + Clear display when an answer is displayed and a numeric point
    is inserted
  + Add GUI for unit conversations (bgo#539830)
  + Fix the definition of ounces
  + Remove trailing whitespace when entering super-/subscript mode
    (bgo#631988)
  + Calculate answers in separate thread (bgo#576371)
  + Stop '*'+backspace+'*' being converted into '^'
  + Updated translations
- Changes from version 5.91.0:
  + Port to GTK+-3 (bgo#630115)
  + Don't crash on pasting empty clipboard
  + Mark more strings as translatable (bgo#630899)
  + Make calculator window resizable (bgo#630594)
  + Put back visible thousands separators (bgo#628908)
  + Make thousands separators and radix points respect the users
    locale
  + Updated translations
- Move to pkgconfig()-style BuildRequires:
  + Old ones: gtk2-devel, libxml2-devel.
  + New ones: gio-2.0, gtk+-3.0, libxml-2.0.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Wed Nov 24 2010 dimstar@opensuse.org
- Update to version 5.32.2:
  + Fix incorrect calculation of tanh
  + Re-fix broken thousands separator code.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 5.32.1:
  + bgo#629381: Fix crash when pasting with empty clipboard
  + bgo#628908: Fix broken thousands separators code
  + Stop '*'+backspace+'*' being converted into '^'
  + Fix the definition of ounces
  + Fix locale initialization
  + Handle Han digits (〇〡〢〣〤〥〦〧〨〩)
  + Updated translations.
* Fri Oct  8 2010 vuntz@opensuse.org
- Do not package translations twice.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 5.32.0:
  + Updated translations.
* Mon Aug 30 2010 dimstar@opensuse.org
- Update to version 5.31.91:
  + Increase accuracy of internal calculations.
  + Don't crash printing numbers when they get too large.
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 5.31.90:
  + Updated translations.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 5.31.6:
  + Fix double pasting into display with middle button
  + Add a11y names to widgets
- Changes from version 5.31.5:
  + Call gsettings_sync() before quit
- Remove gconf2-devel BuildRequires and %%gconf_schemas_prereq. Do
  not pass --disable-schemas-install to configure, since this is
  needed for gconf only.
- Use %%glib2_gsettings_schema_* macros.
* Thu Jul  8 2010 dimstar@opensuse.org
- Update to version 5.31.4:
  + Show currency conversion below display
  + Use gsettings instead of gconf
- Changes from version 5.31.3:
  + Support complex trigonometry
  + Add complex argument button to scientific mode
  + Make popup button for additional functions, with integer/
    fractional component, floor, ceiling, round and sign functions.
- Changes from version 5.31.2:
  + Replace backspace button with undo button
  + Remove memory buttons from basic mode (too complex)
  + Support complex arithmetic
- Changes from version 5.31.1:
  + Dynamically load button layouts to speed up startup time
  + bgo#157962: Add colours to buttons
  + Merge advanced and scientific mode
  + Relayout buttons
  + Use arrows on superscript buttons (i.e. '↑n' instead of '⎕ⁿ')
  + Don't change window title to match mode (no need to)
  + Rename View menu to Mode
  + bgo#505168: Show answer in bold
  + Reimplement undo and redo
  + bgo#615243: Automatically add missing closing brackets
  + Show all defined variables in variable popups
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 5.30.1:
  + bgo#614489: Fix bug stopping translations from working
  + bgo#614491: Mark strings for translation that were missing
  + bgo#614875: Fix memory leak in gcalccmd and failure to quit on
    EOF
  + bgo#614979: Make inverses of variables work
  + bgo#615667: Make --help-gtk work
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 5.30.0:
  + Fix errors in variable exponents (e.g. xy²)
  + Handle powers in convesion units, (e.g. 1m² in mm²)
  + Don't clear ans when clearing display (bgo#613552)
  + Handle equations like (x+3y)(2x-4y)
* Tue Mar 23 2010 vuntz@opensuse.org
- Drop libsoup-devel BuildRequires: it's not needed anymore since
  2.29.92.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 5.29.92:
  + Add shortcuts to base buttons (Ctrl+B, Ctrl+O, Ctrl+D, Ctrl+H)
  + Convert number in display if it has a base and a base button is
    pressed
  + Make scientific notation button behave the same as keyboard
    shortcut (i.e. go into superscript mode).
  + Only allow superscript minus to be entered if can make a valid
    superscript number, otherwise revert to standard minus.
  + Allow hexadecimal numbers to be entered in lower-case
  + Make bit editor active for displayed numbers not in base 10
  + Make variable powers work, e.g. x²
  + bgo#611971: Fix spacebar not working when display has focus
  + Load currency rates when doing typed currency conversion
  + Use GIO instead of libsoup
* Mon Feb 22 2010 dimstar@opensuse.org
- Update to version 5.29.91:
  + Fix bug where backspace deletes all input in locales with no
    thousands separator
  + Make boolean operations work with zero, e.g. "0 XOR 5"
  + bgo#596645 - Don't override space and return when display area
    not selected
  + bgo#602154 - Make window non-resizable
  + Change boolean functions to uppercase (xor -> XOR)
  + Documentation rewritten
  + Modernised build system
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 5.29.90:
  + Miscellaneous string fixes.
  + Updated translations.
* Tue Jan 26 2010 vuntz@opensuse.org
- Update to version 5.29.6:
  + Reimplement automatic ans substitution
  + Make builds less verbose (bgo#607118)
  + De-break function that check if currency rates are out of date
  + Fix shift button keybinding crash
  + Updated translations.
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 5.29.4:
  + Make 0^0 = 1 (bgo#605011)
  + Use superscript digits for scientific notation
  + Clear display when entering a number after an equation
  + Make Ctrl+W a shortcut to quit
  + Updated translations.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 5.29.2:
  + Support conversions in display (e.g. "1 AUD in USD" or "6.2
    inches in meters")
  + Support arbitrary varible names, e.g. set with "name=55"
  + Add a command-line version of gcalctool 'gcalccmd' (bgo#590767)
  + Updated translations.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 5.29.1:
  + New user interface:
  - Window is now shorter to better fix in netbook resolutions
  - Superscript and subscript numbers to allow better notation,
    e.g. "₃√5"
  - Preferences moved into a dialog
  - Functions are now typed, e.g. s+i+n for sine instead of "k"
  - Error messages now displayed below equation, and improved
    descriptions
- Add libsoup-devel and libxml2-devel BuildRequires, to download
  data for currency conversion.
* Fri Sep 25 2009 dimstar@opensuse.org
- Update to version 5.28.0:
  + bgo#595337 - Don't override space bar when buttons are focussed
    as this stops keyboard control
  + bgo#546819 - Handle keycode for '^' used in non-English layouts
    (German, Spanish, etc) and allow '**' to be converted to a '^'
    for layouts that do not support it
  + Updated translations.
* Mon Sep  7 2009 lmedinas@opensuse.org
- Update to version 5.27.92:
  + Fix base conversions
  + Fix disabled help menu
  + Fix duplicate object names in data/financial.ui (bgo#593277)
  + Updated translations.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 5.27.91:
  + Updated translations.
* Tue Aug 11 2009 dominique-obs@leuenberger.net
- Update to version 5.27.90:
  + Fix bug where inserting text in locales without thousands
    separator replaces the whole display.
  + Updated documentation.
  + Updated translations.
* Tue Jul 28 2009 dominique-obs@leuenberger.net
- Update to version 5.27.5:
  + Perform power and factorials before negation so -1!
    and -1^0.5 are valid as in 5.26.x
  + bgo#548884 - Connect functions to solve the function text and
    replace the display with the result
  + bgo#589350 - Change bison syntax to be compatible with
    version 2.3
  + bgo#588591 - Compile with -DGSEAL_ENABLE
  + bgo#589563 - Update gconf descriptions to match translation
    guidelines
  + updated documentation and translations.
* Sun Jul 19 2009 vuntz@novell.com
- Update to version 5.27.4:
  + Update bit editor after shifting (bgo#587545)
  + Use a base-10 internal representation (bgo#585813, bgo#585931,
    bgo#560802)
  + Make padding consistent in GUI (bgo#587292)
  + Support implicit multiply before functions, e.g. "6 log 3"
    (bgo#586812)
  + Use inverse notation for trigonometric functions, i.e. "asin"
  - > "sin⁻¹"
  + Use lowercase notation for trigonometric and logarithm
    functions to look more like standard mathematical notation
  + Put spacing around functions, i.e. "sin" -> " sin "
  + Use subscript for logarithm base two, i.e. "log2" -> "log₂"
  + Added etched border around display (bgo#140836)
  + Rewrote out of date man page (bgo#585997)
  + Updates translations.
* Tue Jun 16 2009 vuntz@novell.com
- Update to version 5.27.3:
  + Percentage operation for addition and subtraction now takes
    percentage of first value (bgo#480207)
  + Use correct UTF-8 mathematical characters (bgo#347630)
  + Focus on the display entry by default
  + Fix broken widget style.  Copy gcalctoolrc to ~/.gcalctoolrc to
    get coloured buttons.
  + Fix missing icon in Help>Contents menu
  + Updated translations.
* Wed May 27 2009 vuntz@novell.com
- Update to version 5.27.2:
  + Add 1's and 2's complement to programming mode (bgo#581253)
  + Add variable word size for bitwise functions (bgo#581253)
  + Remove negative sign from numbers rounded to zero. This is
    only a partial fix as the error value is still visible in
    scientific notation (bgo#560802)
  + Support odd roots of negative numbers (bgo#576973)
  + Keep settings (show zeroes, thousands separator etc) when
    changing modes (bgo#580398)
  + Add a --solve command-line argument
  + Really fix the license text in the about dialog (bgo#579174)
  + Made parser reentrant and part of MP code
  + Remove references to arithmetic/left-to-right precedence from
    the manual (bgo#559734)
  + Fix grammatical errors in manual (bgo#569275)
  + Remove untranslated figures in documentation - they are
    automatically copied from the C documentation (bgo#566680)
  + Updated translations.
- TODO doesn't exist anymore.
* Wed May  6 2009 vuntz@novell.com
- Remove libglade2-devel BuildRequires and add gtk2-devel
  BuildRequires.
* Mon May  4 2009 oddrationale@gmail.com
- Update to version 5.27.1:
  + Convert Glade UI to GtkBuilder UI (bgo#556807)
  + Fix display on startup to be replaced on entry (bgo#576975)
  + Make GConf schemas translatable (bgo#571948)
  + Replace MP number arrays with an MPNumber structure
  + Tidied up error messages (bgo#521184)
  + Tidied up GConf schema, use native GConf types (bgo#493946)
    This will cause the gconf schema to be incompatible with
    gcalctool < 5.26.0. Expect settings to reset to defaults when
    upgrading. Switching between versions will cause resets.
  + Fix missing license text in about dialog (bgo#579174)
  + Update translations
* Sun Apr 12 2009 mboman@suse.de
- Update to version 5.26.1:
  + Fix display on startup to be replaced on entry bgo#575385
  + Translation updates
- Don't package omf files in the main package since they are in
  - lang
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 5.26.0:
  + Fix button expansion (bgo#575385)
  + Removed deprecated test/ directory (bgo#574048)
  + Updated documentation.
  + Translation updates.
- Remove unneeded BuildRequires: gnome-common, scrollkeeper
* Sun Mar  8 2009 vuntz@novell.com
- Review changes.
* Wed Mar  4 2009 lmedinas@gmail.com
- Update to version 5.25.92:
  + Fixed bgo#572881 - Restore number display mode (FIX/SCI/ENG) on
    startup
  + Fixed bgo#527540 - Fix rounding errors in integer power
    calculations
  + Fixed bgo#571007 - Fix error in cosine/tangent calculations
  + Translation updates
  + Documentation updates
* Thu Feb 19 2009 vuntz@novell.com
- Review changes.
* Tue Feb 17 2009 lmedinas@gmail.com
- Update to version 5.25.91:
  + Initialise GType system so usage of GConf doesn't cause crashes
  + Rework command-line arguments to be standard
  + Correctly handle decimal points for languages not using '.'
  + Fix shortcut keys so standard menu keys work
  + Documentation updates
  + Translation updates
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Feb  4 2009 lmedinas@gmail.com
- Update to version 5.25.90:
  + Fixed incorrect bit shift operation
  + Documentation updates
  + Translation updates
* Wed Jan 28 2009 lmedinas@gmail.com
- Update to version 5.25.5:
  + Documentation updates
  + Translation updates
* Fri Jan 23 2009 vuntz@novell.com
- Minor cleanups in spec file, including less BuildRequires.
* Tue Jan  6 2009 mboman@suse.de
- Update to version 5.25.4:
  + Translation updates
* Sat Dec 20 2008 mboman@suse.de
- Update to version 5.25.3:
  + Made exponential numbers work without a sign, e.g. '1e2' works
    the same as '1e+2'
  + Correctly calculate exponential numbers in binary mode and
    convert correctly when changing bases
  + Fix broken accelerator keys from changes in 5.25.2
  + Changed the scientific UI so that inverse operations (e.g. Ln/e^x) are
    controlled by the shift key.
  + Fixed crash where financial dialogs are activated from other modes on
    startup
  + Give binary invert operation higher precedence so that ~X and X == 0
  + Fixed calculation errors for boolean operations on very large numbers
  + Always read configuration from /apps/gcalctool not /apps/(appname) as
    the application
    name is different when symlinked (e.g. the gnome-calculator symlink)
  + Correct gconf key names in man page
  + Added a programming mode that contains the bit editor
  + Made finacial operations GUI-based not register based
  + Added Gross Profit Margin Ration Financial Function
  + Don't clear display when changing modes and allow all functions to work
    in all non-basic modes
  + Set decimal point label to be based on LC_NUMERIC as users can set
    their numerical representation to different to their language settings
  + More refactoring in MP math library
  + Fixed GtkSpinButton warning
  + Only update bit panel when display contains a solved number
  + Remove inline declaration so can compile in C89
  + Open help with gtk_show_uri()
  + Translation updates
- Remove gcalctool-5.19.92-correct-help-uri.patch. Code changed
* Wed Nov  5 2008 jpr@novell.com
- Drop gcalctool-59753_59377_59378.patch (was bnc5724), code is
  useless, unlikely to solve a real world problem, dangerous and
  upstream changed a lot
* Mon Oct 20 2008 mboman@suse.de
- Update to version 5.24.1:
  + Fixed GtkSpinButton warning. bgo#553965
  + Only update bit panel when display contains a solved number. bgo#548690
  + gcalctool/gtk.c: Remove inline declaration so can compile in C89,
    bgo#553307
* Wed Oct  1 2008 mboman@suse.de
- Update to version 5.24.0:
  + Translation updates
* Fri Sep 12 2008 maw@suse.de
- Update to version 5.23.92:
  + Updated translations.
* Tue Sep  2 2008 mboman@novell.com
- Updated to 5.23.91:
  + Fix packing for modulus button (bgo#548880)
  + Change from OnlyShowIn=GNOME;XFCE; to NotShowIn=KDE; so
    other desktops can use GCalctool (bgo#518862).
* Tue Aug 26 2008 mboman@novell.com
- Updated to 5.23.90:
  + Fix some small memory leaks (bgo#547942)
  + More work tidying up MP code (bgo#524091)
* Tue Aug  5 2008 captain.magnus@opensuse.org
- Updated to 5.23.6
  + Deprecated left-to-right mode (Bug bgo#500994).
  + Updated remaining documentation (bg, zh_CN, zh_HK, zh_TW) to gnome-doc-utils (Robert Ancell, Bug bgo#336104)
  + Changed icon from deprecated 'gnome-calculator' to 'accessories-calculator') (Matthias Clasen, Bug bgo#545074)
  + Fix regression in factorial operation (Klaus Niederkrueger)
  + Made trigonometric button text translatable (Yuri Penkin, Bug bgo#540196)
  + More work tidying up MP code (Klaus Niederkrueger, Robert Ancell, Bug bgo#524091)
  + Updated Japanese documentation to gnome-doc-utils (Claude Paroz, Takeshi Aihana, Bug bgo#336104)
  + Added workaround to stop display disappearing when editing large displays (Bug bgo#524602)
  + Applied second mp math tidy up patch from  Klaus Niederkrueger (Bug bgo#524091)
  + Updated translations
* Mon Jun 30 2008 maw@suse.de
- Fix the installation of an icon.
* Fri Jun 20 2008 maw@suse.de
- Update to version 5.23.4:
  + Bugs fixed: bgo#524602, bgo#524091, bgo#527669, bgo#527669,
    bgo#530532, bgo#527318, bgo#526094, bgo#527669, bgo#527545,
    and bgo#524602
- Drop the following obsolete patches: gcalctool-c-style.patch,
  gcalctool-grouping.patch, and gcalctool-localized-radix.patch.
* Mon Apr 21 2008 sbrabec@suse.cz
- Fixed localized radix (bgo#527669).
* Fri Apr 18 2008 sbrabec@suse.cz
- Fix grouping and brokenness in some locales (bgo#527669).
* Thu Apr 10 2008 sbrabec@suse.cz
- Updated to version 5.22.1:
  * Fix for bug where the initial zero in the display was not
    cleared (bgo#520525)
  * Support bracket and multiply keys on non-english keyboards
    (bgo#521620 and bgo#526671)
  * The replacement of sprintf() and strcpy() with the safer
    snprintf() and strncpy() (bgo#520769)
  * Remove a .svn directory from the release tarball (bug#524025)
  * Updated translations.
  * New maintainer.
- Removed patch re-enabling deprecated symbols.
- Fixed snprintf buffer overflow (bgo#527318).
* Tue Mar 25 2008 rodrigo@suse.de
- Tag patches and made them follow naming conventions
* Tue Mar 11 2008 vuntz@suse.de
- Update to version 5.22.0:
  + Fix for bgo#520474 - Calculator uses 06 in place of decimal.
* Tue Mar  4 2008 maw@suse.de
- Update to version 5.21.92:
  + Change Help->Help menu to Help->Contents to match HIG (bgo#514812)
  + Fix for bgo#515326 - translation issues
  + Unmark bitcalculating strings for translation (bgo#515326)
  + Change help menu shortcut from Ctrl+H to F1 to match HIG (bgo#514812)
  + Remove help/it/Makefile, switching to gnome-doc-utils
  + Fix for bgo#514233 - Title not translated
  + Fix for bgo#513868 - Switching mode clears values but not
    "Malformed expression" in statusbar.
  + Fix for bgo#513218 - Parsing not handling things the way a
    "normal" calculator would.
  + Fix for bgo#482666 - XML errors in gcalctool de translation.
  + Fix typo (Retreive -> Retrieve).
* Fri Feb  1 2008 maw@suse.de
- Update to version 5.21.90:
  + Many bug fixes; see the NEWS file for a blow-by-blow account.
* Mon Sep 17 2007 gekker@suse.de
- Update to version 5.20.0
  + Update Translations.
* Fri Sep 14 2007 hpj@suse.de
- Add gcalctool-5.19.92-correct-help-uri.patch, which allows us
  to find help residing in help-bundle/.
* Mon Sep 10 2007 maw@suse.de
- Update to version 5.19.92:
  + Cosmetic version bump.
* Fri Aug 31 2007 maw@suse.de
- Update to version 5.19.91:
  + Fixed b.g.o #467442 - gcalctool does not appear in xfce4 menu.
* Thu Aug  9 2007 maw@suse.de
- Fix up the lang subpackage.
* Wed Aug  8 2007 mauro@suse.de
- Split out a -lang subpackage
- Add %%fdupes stuff
* Thu Aug  2 2007 maw@suse.de
- Update to version 5.19.6:
  + Bugs (bugzilla.gnome.org) fixed: #439985, #448263, #450790,
    [#451286], #439415, and #459702
- Respin gcalctool-deprecated.patch.
* Fri Jul 27 2007 maw@suse.de
- Go all out disabling the disablement of deprecated features
- Use %%fdupes.
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Fri Mar 30 2007 aj@suse.de
- Fix BuildRequires.
* Fri Mar  9 2007 maw@suse.de
- Update to version 5.9.12
  - changes include:
  * All copyright messages updated for 2007.
  * Fixed bug #358782. Fixup sloppy string handling.
  * Fixed bug #364410.  Incorrectly rounded pi constant.
  * Fixed bug 359291 - crash when localized decimal point is greater than
    1 char. Removed the bogus assert.
  * Fixed bug #358337 - gcalctool no longer crashes in the Oriya locale due
    to sloppy string handling.
  * Fixed bug #354730 - crash in Calculator: running 3x10^38 using bi..
  * Fixed bug #357208 - Bitcalculating extension needs to support negative
    numbers
  * Fixed bug #157961 - Bitcalculating extension for gcalctool.
  * Fixed bug #355648 - Error reporting should be consistent.
  * Fixed bug #135140 - percent operator works not as expected.
  * Fixed bug #349981 - gcalctool should save screen position for next start.
* Thu Mar  1 2007 sbrabec@suse.cz
- Fixed icon.
* Mon Jan 15 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Oct 12 2006 ro@suse.de
- added gnome-doc-utils-devel to buildreq
* Sat Sep 30 2006 aj@suse.de
- Cleanup BuildRequires.
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 5.8.24
- Released a gcalctool tarball for GNOME 2.16.0 (Final)
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 5.8.23
- Removed several chunks of code that were surronded by #if 0/#endif
- Fixed bug #350341 gcalctool now builds again with gcc v2.95
* Mon Aug 21 2006 jhargadon@suse.de
- update to version 5.8.20
- Released a gcalctool tarball for GNOME 2.16.0 (beta2)
* Wed Aug  2 2006 jhargadon@suse.de
  * More work on bug #347700.  Added another "Note to translators"
  comment for the Abs button labels.
  * Fixed bug #348452. Removed line for help/sv/Makefile.in
  * Released a gcalctool tarball for GNOME 2.16.0 (beta1).
  * Work on bug #347700. Added a "Note to translators" comment for the
  Bksp and Clr button labels.
  * Fixed bug #343150. Gcalctool no longer crashes when switching to
  scientific mode.
  * Adjusted configure.in so that gcalctool now requires intltool v0.35.0.
  * Fixup compiler warnings from inclusion of last patch.
  * Fixed bug #163538 (http://bugzilla.gnome.org/show_bug.cgi?id=163538)
  Backspace results in mal-formed expression.
  * = button is now also a one step undo. (This feature was temporary
  disabled by the previous redo/undo patch.)
  * Removed gotos from do_expression function. (This change might add
  unstability as this is a major change to the expression mode state
  machine.)
  * Functions (such as sin, cos, tan..) can use previously calculated value.
  * First cut at an Undo/Redo implementation for use with the arithmetic
  operator precedence mode.
  * Respun the gcalctool tarball for GNOME 2.15.1 as the po/*.po files
  were missing.
  * Removed .../po/Makefile.in.in. Shouldn't have been in CVS.
  * Fixed bug #337897. Changes to use po/LINGUAS file.
  * Fixed bug #338220. The 'Show trailing zeroes' option in the View menu
  should now be correctly set [in]sensitive depending upon which mode
  it's in.
  * Fixed bug #332023. The bitwise operators now work in arithmetic operator
  precedence mode, when you use them with the result of a previous operation.
  * Fixed bug #327729. The fields in the memory register window were not
  correctly aligned in some themes.
  * Fixed bug #330867.  Added License info to the Gcalctool About dialog.
  * Fixed bug #335095. Gcalctool no longer displays the current mode in
  the title bar when in Basic mode (due to lack of space).
  * Fixed bug #335236. Gcalctool schemas files should be installed if
  built with "--without-gnome".
  * Adjustments to the AOP code so that e to the power of x gives the
  correct answer at high precision.
  * Fix for bug #333078. cvs fails to build due to bg translation of help.
  * Inclusion of a translation of gcalctool help for the bg locale.
  * Refixed bug #323150. The recent changes to the square root and
  subtraction button labels broke the token parser for arithmetic
  operator precedence.
  * Fixed bug #327124. Changes to fix bug #326344 had the side-effect of
  causing the CE button to no longer work correctly.
  * Fixed bug #327214. The results from performing trig functions were not
  being passed on to future calculations correctly (in non-arithmetic
  operator precedence mode).
  * Gcalctool now uses U+00F7 (DIVISION SIGN) instead of U+2215 (DIVISION SLASH)
  for label on division button.
  * Fixed bug #323149. Gcalctool now uses the Unicode symbols for division,
  multiplication, plus/minus, minus and square root.
  * Fixed bug #326344. The bit display of large numbers (in non-arithmetic
  operator precedence mode with the scientific view) now hopefully works
  correctly.
  * Fixed bug #142824. Gcalctool no longer ignores locale specific numeric
  point in arithmetic operator precedence mode.
  * Adjusted all the copyright messages to include 2006.
  * Fixed bug #317378 (http://bugzilla.gnome.org/show_bug.cgi?id=317378)
  Gcalctool no longer crashes when you double click the 0 in the display area.
  * Final fix for bug #153854. Now handles the case where the first thing
  the user does is change mode (Basic, Financial, Advanced, Scientific)
  in AOP mode.
  * Fixed bug #323150. Sqrt (and other similar operations) no longer fail
  in non-English locales
  * Fixed bug #324001. Primary Selection (middle mouse button) is now working.
  * More work on bug #153854. Similar change to that made on 15th November
  2005, this time for arithmetic operator precedence mode.
  * Slight fixup for bug #157961. The toggling of the first bit in the
  bit panel wasn't working correctly.
  * Implemented enhancement request #148104 for arithmetic precedence mode.
  The modulo operation. See entry below for more details.
  * Implemented enhancement request #148104 for non-arithmetic precedence
  mode. Added in a modulo operation. This is available in Scientic Mode.
  A Mod B return the remainder when you divide A by B. A and B must be
  integers. Keyboard shortcut for this operation is "M".
  * Fixed bug #162453. The memory register dialog now uses GtkEntry widgets
  to display the register values. Gnopernicus can now correctly speak the
  contents of each memory register. There is also a close button to easily
  dismiss this dialog.
  * Fix to prevent invalid numeric entry in arithmetic operator precedence
  mode, depending upon the current base.
* Fri May  5 2006 sreeves@suse.de
- Fix for 167218 - change name
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 sbrabec@suse.cz
- Prevent bad calculations with localized decimal point.
  http://bugzilla.gnome.org/show_bug.cgi?id=142824#c17
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Mon Sep  5 2005 rodrigo@suse.de
- Update to version 5.6.31 (part of GNOME 2.12)
* Mon Aug 22 2005 rodrigo@suse.de
- Update to version 5.6.28
* Mon Aug  8 2005 rodrigo@suse.de
- Update to version 5.6.26
* Tue Aug  2 2005 gekker@suse.de
- Update to version 5.6.25
* Fri Jul 22 2005 gekker@suse.de
- Update to version 5.6.21
* Fri Jun 17 2005 gekker@suse.de
- Update to version 5.6.14
* Wed Mar  9 2005 gekker@suse.de
- Update to version 5.5.41 (GNOME 2.10).
* Wed Mar  2 2005 gekker@suse.de
- Update to version 5.5.40
* Thu Feb 10 2005 gekker@suse.de
- Update to version 5.5.34
* Sat Feb  5 2005 gekker@suse.de
- Update to version 5.5.29
* Tue Feb  1 2005 sbrabec@suse.cz
- Force include gi18n.h.
- Fixed implicit declaration.
* Tue Jan  4 2005 gekker@suse.de
- Update to version 5.5.9
- Remove decimal.patch (upstreamed).
- Fixed patch for ximian bugs mentioned below (mostly upstreamed).
- Added gnome-icon-theme to neededforbuild, now required.
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Wed Aug 25 2004 clahey@suse.de
- Cache gcalctool help and show gcalctool in khelpcenter.
* Tue Jun 22 2004 sagarwala@suse.de
- Added patch for the following bugs in ximian bugzilla #59753, #59377 and #59378
* Thu May 27 2004 sbrabec@suse.cz
- Added patch for localized decimal point.
  http://bugzilla.gnome.org/show_bug.cgi?id=142824
* Wed May  5 2004 sbrabec@suse.cz
- Updated to version 4.3.51 (GNOME 2.6).
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
- Fixed %%doc attributes (#33163).
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 4.3.44.
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Mon Feb  9 2004 hhetter@suse.de
- updated to version 4.3.16 [GNOME2.4.2]
* Thu Oct  9 2003 sbrabec@suse.cz
- Updated %%doc.
* Wed Oct  8 2003 sbrabec@suse.cz
- Added new SuSE package, version 4.3.3 (for GNOME 2.4).
